# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# 1.0.0 (2022-07-28)

### chore

- initial deployment of charts-python package ([af68e9f](https://github.com/visa/visa-chart-components/commit/af68e9fc88253bb4c40391ae6b78441aca570e76))

### BREAKING CHANGES

- initial deployment of charts-python package

Co-authored-by: Chris DeMartini <74268675+chris-demartini@users.noreply.github.com>
